@@ -3,12 +3,8 @@ package Log::Mini;
 use strict;
 use warnings;
 
-our $VERSION = "0.1.1";
+our $VERSION = "0.2.0";
 
-use Log::Mini::LoggerFILE;
-use Log::Mini::LoggerSTDERR;
-
-use Data::Dumper;
 use feature qw/say/;
 
 
@@ -19,9 +15,15 @@ sub new {
     $type = 'stderr' unless defined $type;
 
     if ( $type eq 'file' ) {
+        require Log::Mini::LoggerFILE;
         return Log::Mini::LoggerFILE->new(@_);
     }
+    elsif ( $type eq 'null' ) {
+        require Log::Mini::LoggerNULL;
+        return Log::Mini::LoggerNULL->new(@args);
+    }
     else {
+        require Log::Mini::LoggerSTDERR;
         return Log::Mini::LoggerSTDERR->new(@args);
     }
 }
@@ -42,13 +44,13 @@ Log::Mini - It's a very simple logger which can log your messages to a file or S
 
     use Log::Mini;
 
-    my $logger = Log::Mini->get_logger(); #STDERR logger used by default. Error is default log level
+    my $logger = Log::Mini->new(); #STDERR logger used by default. Error is default log level
     $logger->error('Error message');
 
-    my $debug_logger = Log::Mini->get_logger('stderr', level => 'debug'); #STDERR logger used by default
+    my $debug_logger = Log::Mini->new('stderr', level => 'debug'); #STDERR logger used by default
     $debug_logger->error('Error message');
 
-    my $file_logger = Log::Mini->get_logger(file => 'log_file.log');
+    my $file_logger = Log::Mini->new(file => 'log_file.log');
     $file_logger->info('message to log file');
 
     #prevent buffered output. May slow down your application!
@@ -60,6 +62,10 @@ Log::Mini - It's a very simple logger which can log your messages to a file or S
     #log method for better compatibility
     $logger->log('info', 'information message');
 
+    #Null logger - drops all messages to /dev/null
+    my $logger = Log::Mini->new('null);
+    $logger->error('Error message'); #Message will be dropped
+
 
 =head1 DESCRIPTION
 
